/***************************************************************************
 *            menage_db_win-callbacks.c
 *
 *  Sat Oct 22 14:31:24 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomcio-j@o2.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gi18n-lib.h>
#include <stdio.h>

#include "menage_db_win-callbacks.h"
#include "interface-fun.h"
#include "menage_db-fun.h"

gboolean
on_menage_db_win_delete_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	destroy_window (widget);
	return FALSE;
}	

void
on_authors_but_clicked                 (GtkButton       *button,
                                        gpointer         user_data)
{
	set_menage_db_win_data_type (GTK_WIDGET (button), 0);
}

void
on_generes_but_clicked                 (GtkButton       *button,
                                        gpointer         user_data)
{
	set_menage_db_win_data_type (GTK_WIDGET (button), 1);
}

void
on_pub_houses_but_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
	set_menage_db_win_data_type (GTK_WIDGET (button), 2);
}

void
on_translators_but_clicked             (GtkButton       *button,
                                        gpointer         user_data)
{
	set_menage_db_win_data_type (GTK_WIDGET (button), 3);
}

void
on_languages_but_clicked               (GtkButton       *button,
                                        gpointer         user_data)
{
	set_menage_db_win_data_type (GTK_WIDGET (button), 4);
}

void
on_items_list_cursor_changed           (GtkTreeView     *treeview,
                                        gpointer         user_data)
{
	GladeXML	*xml;
	GtkWidget	*widget;
	
	xml = glade_get_widget_tree (GTK_WIDGET (treeview));
	widget = glade_xml_get_widget (xml, "item_name_en");
	gtk_entry_set_text (GTK_ENTRY (widget), "");

	set_widget_sensinitive (widget, "item_remove_but", TRUE);
}

void
on_item_add_but_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	GladeXML	*xml;
	GtkWidget	*widget;
	
	xml = glade_get_widget_tree (GTK_WIDGET (button));
	widget = glade_xml_get_widget (xml, "item_name_en");
	
	add_item ( (gpointer) gtk_entry_get_text (GTK_ENTRY (widget)));
	load_table (widget);

	/*	Czyscimy po sobie	*/
	widget = glade_xml_get_widget (xml, "item_name_en");
	gtk_entry_set_text (GTK_ENTRY (widget), "");
	set_widget_sensinitive (widget, "item_remove_but", FALSE);
	set_widget_sensinitive (widget, "item_add_but", FALSE);
}

void
on_item_remove_but_clicked             (GtkButton       *button,
                                        gpointer         user_data)
{
	GladeXML			*xml;
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*widget;
	gint				item_id;
	gboolean			result;
	
	xml = glade_get_widget_tree (GTK_WIDGET (button));
	widget = glade_xml_get_widget (xml, "items_list"); 
	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
	gtk_tree_selection_get_selected (selection, &model, &iter);
	
	gtk_tree_model_get (model, &iter, 0, &item_id, -1);
	
	result = check_if_item_is_used (item_id, menage_db_mode);
	if (result == TRUE)	{
		remove_item (item_id, menage_db_mode);
		load_table (widget);
		
		set_widget_sensinitive (widget, "item_remove_but", FALSE);
	}
}

void
on_menage_db_close_but_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
	destroy_window (GTK_WIDGET (button));
}

void
on_item_name_en_changed                (GtkEditable     *editable,
                                        gpointer         user_data)
{
	GtkWidget	*widget;
	GladeXML	*xml;
	
	xml = glade_get_widget_tree (GTK_WIDGET (editable));
	widget = glade_xml_get_widget (xml, "item_name_en");	
	
	/*	Liczymy ilosc znakow wpisanych do GtkEntry o nazwie 'item_name_en'
	 *	jezeli jest rowna 0 to deaktywujemy przycisk 'item_add_but', jezeli jest 
	 *	wikesza od 0 to aktywujemy przycisk	*/

	if (strcmp (gtk_entry_get_text (GTK_ENTRY (widget)), "") == 0)
		set_widget_sensinitive (widget, "item_add_but", FALSE);
	else
		set_widget_sensinitive (widget, "item_add_but", TRUE);
}
