/***************************************************************************
 *            s_book-fun.c
 *
 *  Mon Oct 31 16:05:03 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomcio-j@o2.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
/*=====================================================================
 *	Plik zawiera funkcje zwiazane tylko z obsluga ksiazek jednotomowych
 *====================================================================*/
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gi18n-lib.h>
#include <stdio.h>

#include "s_book-fun.h"
#include "database-fun.h"
#include "interface-fun.h"

#define VERY_SHORT_STRING	12
#define SHORT_STRING		128
#define MEDIUM_STRING		256
#define	LONG_STRING			1024
#define	VERY_LONG_STRING	6144

/*
 *	Funkcja pobiera wartosci wszystkich pol i przekazuje je innym funkcjom w
 *	postaci struktury zdefiniowanej w naglowku 's_book-fun.h'. W ramach 
 *	przypomnienia powiem, ze dane zostaly juz sprawdzone przez funkcje 
 *	'check_book_data' zdefiniowana w pliku book-fun.h
 */

SingleVolumeStruc	*s_get_data_from_win	(GtkWidget	*widget)	{
	SingleVolumeStruc	*book_data;
	GladeXML			*xml;
	GtkTextBuffer		*text_buffer;
	GtkTextIter			text_start;	
	GtkTextIter			text_end;
	GtkWidget			*tmp;
	gint				status;
	gint				result;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	book_data = g_new (SingleVolumeStruc, 1);
	xml = glade_get_widget_tree (widget);
	g_printf (">>> Getting values from 's_book_win'...\n");
	
	/*	Pobieramy ID ksiazki	*/
	tmp = glade_xml_get_widget (xml, "book_id_lb");
	if (strlen (gtk_label_get_text (GTK_LABEL (tmp))) > 0)	{
		sscanf (gtk_label_get_text (GTK_LABEL (tmp)), "%d", &book_data->id);
	}
	
	/*	Pobieramy wartosc pola 'title_en'	*/
	tmp = glade_xml_get_widget (xml, "title_en");
	g_sprintf (book_data->title, "%s", gtk_entry_get_text (GTK_ENTRY (tmp)));
	
	/*	Pobieramy wartosc pola 'genere_en'	*/
	tmp = glade_xml_get_widget (xml, "genere_en");
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		book_data->genere = 0;
	}
	else	{
		book_data->genere = get_genere_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
	} 
	
	/*	Pobieramy wartosc pola 'publish_house_en'	*/
	tmp = glade_xml_get_widget (xml, "publish_house_en");
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		book_data->publish_house = 0;
	}
	else	{
		book_data->publish_house = get_publish_house_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
	}
	
	/*	Pobieramy wartosc pola 'language_en'	*/
	tmp = glade_xml_get_widget (xml, "language_en");
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		book_data->language = 0;
	}
	else	{
		book_data->language = get_language_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
	}
	
	/*	Pobieramy wartosc pola 's_first_author_en'	*/
	tmp = glade_xml_get_widget (xml, "s_first_author_en");
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		book_data->first_author = 0;
	}
	else	{
		book_data->first_author = get_author_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
		
		/*	Pobieramy wartosc pola 'second_author_en'	*/
		tmp = glade_xml_get_widget (xml, "second_author_en");
		if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
			book_data->second_author = 0;
		}
		else	{
			book_data->second_author = get_author_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
		}
		
		/*	Pobieramy wartosc pola 'third_author_en'	*/
		tmp = glade_xml_get_widget (xml, "third_author_en");
		if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
			book_data->third_author = 0;
		}
		else	{
			book_data->third_author = get_author_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
		}
	}
	
	/*	Pobieramy wartosc pola 'orginal_title_en'	*/
	tmp = glade_xml_get_widget (xml, "orginal_title_en");
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		g_sprintf (book_data->orginal_title, "%s", "");
	}
	else	{
		g_sprintf (book_data->orginal_title, "%s", gtk_entry_get_text (GTK_ENTRY (tmp)));
	}
	
	/*	Pobieramy wartosc pola 'orginal_language_en'	*/
	tmp = glade_xml_get_widget (xml, "orginal_language_en");
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		book_data->orginal_language = 0;
	}
	else	{
		book_data->orginal_language = get_language_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
	}
	
	/*	Pobieramy wartosc pola 'isbn_en'	*/
	tmp = glade_xml_get_widget (xml, "isbn_en");
	g_sprintf (book_data->isbn, "%s", gtk_entry_get_text (GTK_ENTRY (tmp)));
	
	/*	Pobieramy wartosc pola 'publish_year_spin'	*/
	tmp = glade_xml_get_widget (xml, "publish_year_spin");
	book_data->publish_year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (tmp));
	
	/*	Pobieramy wartosc pola 'pages_number_spin'	*/
	tmp = glade_xml_get_widget (xml, "pages_number_spin");
	book_data->pages = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (tmp));
	
	/*	Pobieramy wartosc pola 's_first_translator_en'	*/
	tmp = glade_xml_get_widget (xml, "s_first_translator_en");
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		book_data->first_translator = 0;
	}
	else	{
		book_data->first_translator = get_translator_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
		
		/*	Pobieramy wartosc pola 'second_translator_en'	*/
		tmp = glade_xml_get_widget (xml, "second_translator_en");
		if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
			book_data->second_translator = 0;
		}
		else	{
			book_data->second_translator = get_translator_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
		}
		
		/*	Pobieramy wartosc pola 'third_translator_en'	*/
		tmp = glade_xml_get_widget (xml, "third_translator_en");
		if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
			book_data->third_translator = 0;
		}
		else	{
			book_data->third_translator = get_translator_id (gtk_entry_get_text (GTK_ENTRY (tmp)));
		}
	}
	
	/*	Pobieramy wartosc pola 'description_en'	*/
	tmp = glade_xml_get_widget (xml, "description_text");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_get_bounds (text_buffer, &text_start, &text_end);
	g_sprintf (book_data->description, "%s", gtk_text_buffer_get_text (text_buffer, &text_start, &text_end, TRUE));
	
	return	book_data;
}

/*
 *	Funkcja sprawdza, czy wartosc pol takich jak np.: 'Language', 'Genere' itp.
 *	znajduje sie juz w bazie danych. Jezeli owa wartosc nie istnieje w bazie 
 *	dancyh, user otrzymuje propozycje dodania tej wartosci wprost z okna
 *	dodawania/edycji ksiazki, a nie poprzez okno 'menage_db_win'
 */

void	s_check_linked_book_data		(GtkWidget		*widget)	{
	GladeXML			*xml;
	GtkWidget			*tmp;
	gboolean			result;
	gint				status;
	gint				rows;
	gchar				sql_query	[SHORT_STRING];
	gchar				string		[MEDIUM_STRING];
	
	sqlite3_stmt		*db_row;
	
	xml = glade_get_widget_tree (widget);
	
	/* Sprawdzamy pole 'Genere'	*/
	tmp = glade_xml_get_widget (xml, "genere_en");
	
	/*	Jezeli pole jest puste to je pomijamy	*/
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
		g_sprintf (sql_query, "SELECT COUNT(id) FROM generes WHERE genere=\'%s\';",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
		rows = count_returned_rows (sql_query);
		if (rows == 0)	{
			g_sprintf (string, _("There is no genere \'%s\' in database, do you want "
						"to add it now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
			result = show_question_dlg (_("New genre"), string, 0);
			if (result == TRUE)	{
				g_sprintf (sql_query, "INSERT INTO generes (id, genere) VALUES (NULL, \'%s\');",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
				sqlite3_prepare (database, sql_query, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Adding new genere, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			}
		}
	}
	/* Sprawdzamy pole 'Publish house'	*/
	tmp = glade_xml_get_widget (xml, "publish_house_en");
	
	/*	Jezeli pole jest puste to je pomijamy	*/
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
		g_sprintf (sql_query, "SELECT COUNT(id) FROM publish_houses WHERE publish_house=\'%s\';",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
		rows = count_returned_rows (sql_query);
		if (rows == 0)	{
			g_sprintf (string, _("There is no publish house \'%s\' in database, do you want "
						"to add it now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
			result = show_question_dlg (_("New publish house"), string, 0);
			if (result == TRUE)	{
				g_sprintf (sql_query, "INSERT INTO publish_houses (id, publish_house) VALUES (NULL, \'%s\');",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
				sqlite3_prepare (database, sql_query, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Adding new publish house, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			}
		}
	}
	
	/* Sprawdzamy pole 'Languages'	*/
	tmp = glade_xml_get_widget (xml, "language_en");
	
	/*	Jezeli pole jest puste to je pomijamy	*/
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
		g_sprintf (sql_query, "SELECT COUNT(id) FROM languages WHERE language=\'%s\';",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
		rows = count_returned_rows (sql_query);
		if (rows == 0)	{
			g_sprintf (string, _("There is no language \'%s\' in database, do you want "
						"to add it now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
			result = show_question_dlg (_("New language"), string, 0);
			if (result == TRUE)	{
				g_sprintf (sql_query, "INSERT INTO languages (id, language) VALUES (NULL, \'%s\');",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
				sqlite3_prepare (database, sql_query, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Adding new language, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			}
		}
	}
	
	/* Sprawdzamy pole autorow	*/
	tmp = glade_xml_get_widget (xml, "s_first_author_en");

	/*	Jezeli pole jest puste to je pomijamy	*/
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
		g_sprintf (sql_query, "SELECT COUNT(id) FROM authors WHERE author=\'%s\';",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
		rows = count_returned_rows (sql_query);
		if (rows == 0)	{
			g_sprintf (string, _("There is no author \'%s\' in database, do you want "
						"to add it now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
			result = show_question_dlg (_("New author"), string, 0);
			if (result == TRUE)	{
				g_sprintf (sql_query, "INSERT INTO authors (id, author) VALUES (NULL, \'%s\');",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
				sqlite3_prepare (database, sql_query, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Adding new author, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			}
		}
	}
	
	tmp = glade_xml_get_widget (xml, "second_author_en");
		
	/*	Jezeli pole jest puste to je pomijamy	*/
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
		g_sprintf (sql_query, "SELECT COUNT(id) FROM authors WHERE author=\'%s\';",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
		rows = count_returned_rows (sql_query);
		if (rows == 0)	{
			g_sprintf (string, _("There is no author \'%s\' in database, do you want "
						"to add it now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
			result = show_question_dlg (_("New author"), string, 0);
			if (result == TRUE)	{
				g_sprintf (sql_query, "INSERT INTO authors (id, author) VALUES (NULL, \'%s\');",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
				sqlite3_prepare (database, sql_query, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Adding new author, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			}
		}
	}
		
	tmp = glade_xml_get_widget (xml, "third_author_en");
	
	/*	Jezeli pole jest puste to je pomijamy	*/
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
		g_sprintf (sql_query, "SELECT COUNT(id) FROM authors WHERE author=\'%s\';",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
		rows = count_returned_rows (sql_query);
		if (rows == 0)	{
			g_sprintf (string, _("There is no author \'%s\' in database, do you want "
						"to add it now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
			result = show_question_dlg (_("New author"), string, 0);
			if (result == TRUE)	{
				g_sprintf (sql_query, "INSERT INTO authors (id, author) VALUES (NULL, \'%s\');",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
				sqlite3_prepare (database, sql_query, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Adding new author, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			}
		}
	}
		
	/* Sprawdzamy pole orginalnej wersji jezykowej	*/
	tmp = glade_xml_get_widget (xml, "orginal_language_en");
	
	/*	Jezeli pole jest puste to je pomijamy	*/
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
		g_sprintf (sql_query, "SELECT COUNT(id) FROM languages WHERE language=\'%s\';",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
		rows = count_returned_rows (sql_query);
		if (rows == 0)	{
			g_sprintf (string, _("There is no language \'%s\' in database, do you want "
						"to add it now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
			result = show_question_dlg (_("New language"), string, 0);
			if (result == TRUE)	{
				g_sprintf (sql_query, "INSERT INTO languages (id, language) VALUES (NULL, \'%s\');",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
				sqlite3_prepare (database, sql_query, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Adding new language, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			}
		}
	}
	
	/* Sprawdzamy pola tlumaczy	*/
	tmp = glade_xml_get_widget (xml, "s_first_translator_en");
	
	/*	Jezeli pole jest puste to je pomijamy	*/
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
		g_sprintf (sql_query, "SELECT COUNT(id) FROM translators WHERE translator=\'%s\';",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
		rows = count_returned_rows (sql_query);
		if (rows == 0)	{
			g_sprintf (string, _("There is no tralnslator \'%s\' in database, do you want "
						"to add him now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
			result = show_question_dlg (_("New translator"), string, 0);
			if (result == TRUE)	{
				g_sprintf (sql_query, "INSERT INTO translators (id, translator) VALUES (NULL, \'%s\');",
					gtk_entry_get_text (GTK_ENTRY (tmp)));
				sqlite3_prepare (database, sql_query, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Adding new nranslator, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			}
		}
	}
	
	tmp = glade_xml_get_widget (xml, "s_second_tralslator_check");
	
	/*	Sprawdzamy drugie pole tlumacza, tylko gdy "ptaszek" przy dodatkowym polu
	 *	jest zanzaczony	*/
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (tmp)) == TRUE)	{
		tmp = glade_xml_get_widget (xml, "second_translator_en");
		
		/*	Jezeli pole jest puste to je pomijamy	*/
		if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
			g_sprintf (sql_query, "SELECT COUNT(id) FROM translators WHERE translator=\'%s\';",
						gtk_entry_get_text (GTK_ENTRY (tmp)));
			rows = count_returned_rows (sql_query);
			if (rows == 0)	{
				g_sprintf (string, _("There is no translator \'%s\' in database, do you want "
							"to add him now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
				result = show_question_dlg (_("New author"), string, 0);
				if (result == TRUE)	{
					g_sprintf (sql_query, "INSERT INTO translators (id, translator) VALUES (NULL, \'%s\');",
						gtk_entry_get_text (GTK_ENTRY (tmp)));
					sqlite3_prepare (database, sql_query, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf (">>> Adding new translator, SQLite result: %d\n", status);
					sqlite3_finalize (db_row);
				}
			}
		}
	}

	tmp = glade_xml_get_widget (xml, "s_third_translator_check");
	
	/*	Sprawdzamy trzecie pole tlumacza, tylko gdy "ptaszek" przy dodatkowym polu
	 *	jest zanzaczony	*/
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (tmp)) == TRUE)	{
		tmp = glade_xml_get_widget (xml, "third_translator_en");
		
		/*	Jezeli pole jest puste to je pomijamy	*/
		if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) > 0)	{
			g_sprintf (sql_query, "SELECT COUNT(id) FROM translators WHERE translator=\'%s\';",
						gtk_entry_get_text (GTK_ENTRY (tmp)));
			rows = count_returned_rows (sql_query);
			if (rows == 0)	{
				g_sprintf (string, _("There is no translator \'%s\' in database, do you want "
							"to add him now?"), gtk_entry_get_text (GTK_ENTRY (tmp)));
				result = show_question_dlg (_("New translator"), string, 0);
				if (result == TRUE)	{
					g_sprintf (sql_query, "INSERT INTO translators (id, translator) VALUES (NULL, \'%s\');",
						gtk_entry_get_text (GTK_ENTRY (tmp)));
					sqlite3_prepare (database, sql_query, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf (">>> Adding new translator, SQLite result: %d\n", status);
					sqlite3_finalize (db_row);
				}
			}
		}
	}
}

/*
 *	Funkcja przygotowuje okno dodawania/edycji do uzycia ladujac np. listy autorow, 
 *	gatunkow itd. do odpowiednuch widgetow GtkEntry w oknie.
 */

void		s_prepare_book_win	(GtkWidget	*widget)	{
	GladeXML			*xml;
	GtkListStore		*list;
	GtkTreeIter			iter;
	GtkEntryCompletion	*completion;
	GtkWidget			*tmp;
	gint				status;
	gint				rows;
	sqlite3_stmt		*db_row;
	
	xml = glade_get_widget_tree (widget);	
	g_printf (">>> Preparing window...\n");
	
	/*	Ladujemy autorow	*/
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM authors;");
	g_printf ("\t<<< Loading %d authors...\n", rows);
	if (rows > 0)	{
		sqlite3_prepare (database, "SELECT author FROM authors;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading table \'authors\', SQLite result: %d\n", status);
	
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		
		/*	W koncu ladujemy listy do widgetow...	*/
		/*	Nazwa pola pierwszego autora jest inna w roznych oknach	*/
		tmp = glade_xml_get_widget (xml, "s_first_author_en");	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		tmp = glade_xml_get_widget (xml, "second_author_en");
		completion = gtk_entry_completion_new ();
		gtk_entry_completion_set_inline_completion (completion, TRUE);
		gtk_entry_completion_set_text_column (completion, 0);
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		tmp = glade_xml_get_widget (xml, "third_author_en");	
		completion = gtk_entry_completion_new ();
		gtk_entry_completion_set_inline_completion (completion, TRUE);
		gtk_entry_completion_set_text_column (completion, 0);
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
	}
	
	/* GtkEntry 'genere_en'   */
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM generes;");
	g_printf ("\t<<< Loading %d genres...\n", rows);
	if (rows > 0)	{
		sqlite3_prepare (database, "SELECT genere FROM generes;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading table \'genres\', SQLite result: %d\n", status);
		
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));

		tmp = glade_xml_get_widget (xml, "genere_en");	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);;
	}
	
	/*	Ladujemy wydawnictwa	*/
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM publish_houses;");
	g_printf ("\t<<< Loading %d publish houses...\n", rows);
	if (rows > 0)	{
		sqlite3_prepare (database, "SELECT publish_house FROM publish_houses;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading table \'publish_houses\', SQLite result: %d\n", status);
		
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		
		tmp = glade_xml_get_widget (xml, "publish_house_en");	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);;
	}
	
	/*	Ladujemy jezyki	*/
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM languages;");
	g_printf ("\t<<< Loading %d languages...\n", rows);
	if (rows > 0)	{
		sqlite3_prepare (database, "SELECT language FROM languages;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading table \'languages\', SQLite result: %d\n", status);
		
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		
		tmp = glade_xml_get_widget (xml, "language_en");	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		tmp = glade_xml_get_widget (xml, "orginal_language_en");	
		completion = gtk_entry_completion_new ();
		gtk_entry_completion_set_inline_completion (completion, TRUE);
		gtk_entry_completion_set_text_column (completion, 0);
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
	}
	
	/*	Ladujemy tlumaczy	*/
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM translators;");
	g_printf ("\t<<< Loading %d translators...\n", rows);
	if (rows > 0)	{
		sqlite3_prepare (database, "SELECT translator FROM translators;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading table \'translators\', SQLite result: %d\n", status);
	
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		
		/*	W koncu ladujemy listy do widgetow...	*/
		/*	Nazwa pola pierwszego tlumacza jest inna w roznych oknach	*/
		tmp = glade_xml_get_widget (xml, "s_first_translator_en");	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		tmp = glade_xml_get_widget (xml, "second_translator_en");	
		completion = gtk_entry_completion_new ();
		gtk_entry_completion_set_inline_completion (completion, TRUE);
		gtk_entry_completion_set_text_column (completion, 0);
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		tmp = glade_xml_get_widget (xml, "third_translator_en");	
		completion = gtk_entry_completion_new ();
		gtk_entry_completion_set_inline_completion (completion, TRUE);
		gtk_entry_completion_set_text_column (completion, 0);
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
	}
	set_widget_sensinitive (widget, "s_book_hbox", TRUE);	
}

/*
 *	Funkcja sprawdza poprawnosc wprowadzonych danych do okna dodawania/edycji 
 *	ksiazki. Jezeli dane sa bledne lub jezeli ich nie ma zwracana jest wartosc 
 *	FALSE i wyswietlany jest komunikat z ostrzezeniem.
 *	Sprawdzane sa tylko te dane, ktore sa niezbedne do zapisania ksiazki w bazie 
 *	danych, czyli: tytul i jezyk.
 *	Funkcja sprawdza czy takie pola jak: "Publish house", "Genere", "Author", 
 *	"Translator", "Pages noumber" i "Publish year" sa puste. Jezeli sa zostaje
 *	wyswietlony kominukat z informacja. Poniewaz te pola nie sa wymagane, zostanie
 *	zwrocona wartosc TRUE.
 *	
 *	Przy okazji sprawdzamy, czy pole 'Description' nie zawiera zbyt dlugiego opisu
 *	maksymlna dlugosc to 2000 znakow.
 *
 *	Wartosci argumentu 'mode'
 *	- 0 - okno 's_book_win'
 *	- 1 - okno 'm_book_win'
 */

gboolean	s_check_book_data	(GtkWidget	*widget)	{
	GladeXML		*xml;
	GtkWidget		*tmp;
	GtkWidget		*genere_en;
	GtkWidget		*publish_house_en;
	GtkWidget		*first_author_en;
	GtkWidget		*publish_year_en;
	GtkWidget		*pages_number_en;
	GtkWidget		*first_translator_en;
	GtkWidget		*language_en;
	GtkWidget		*isbn_en;
	GtkTextBuffer 	*text_buffer;
	GtkTextIter		text_start;	
	GtkTextIter		text_end;
	gchar			string					[VERY_SHORT_STRING];
	gint			i;
	
	i = 0;
	
	xml = glade_get_widget_tree (widget);
	/*	Pole 'Title' nie moze byc puste	*/
	tmp = glade_xml_get_widget (xml, "title_en");
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		show_message_dlg (_("Invalid field value"), _("Field \'Title\' can't be empty!"), 1);
		return FALSE;
	}
	
	/*	Sprawdzamy czy pole 'ISBN' jest poprawnie wypelnione	*/
	isbn_en = glade_xml_get_widget (xml, "isbn_en");
	
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (isbn_en))) == 0)
	{
			/*	Nic nie robimy	*/
	}	
	else if (strlen (gtk_entry_get_text (GTK_ENTRY (isbn_en))) < 10)	{
		show_message_dlg (_("Invalid field value"), _("ISBN number is too short"), 1);
		return FALSE;
	}
	else if	(strlen (gtk_entry_get_text (GTK_ENTRY (isbn_en))) == 10)	{
	/*	Wszystkie znaki w plu ISBN musza byc cyframi	*/
		g_sprintf (string, "%s", gtk_entry_get_text (GTK_ENTRY (isbn_en)));
		while (i < 10)	{
			if (g_ascii_isdigit (string [i]) == FALSE)	{
				show_message_dlg (_("Invalid field value"), _("Field \'ISBN\' can't "
								"contain other value than numeric signs!"), 1);
				return FALSE;
			}
			++i;
		}
	}
	
	/*	Sprawdzamy dlugosc testu w polu 'Description'	*/
	tmp = glade_xml_get_widget (xml, "description_text");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_get_bounds (text_buffer, &text_start, &text_end);	
	if (strlen ( gtk_text_buffer_get_text (text_buffer, &text_start, &text_end, TRUE)) > 2000)	{
		show_message_dlg (_("Invalid field value"), _("Description can't be longer than 2000 signs!"), 1);
		return FALSE;
	}
	
	/*	Sprawdzamy czy opcjonalne pola zostaly wypelnione */
	genere_en = glade_xml_get_widget (xml, "genere_en");
	publish_house_en = glade_xml_get_widget (xml, "publish_house_en");
	first_author_en = glade_xml_get_widget (xml, "s_first_author_en");
	publish_year_en = glade_xml_get_widget (xml, "publish_year_spin");
	pages_number_en = glade_xml_get_widget (xml, "pages_number_spin");
	isbn_en = glade_xml_get_widget (xml, "isbn_en");
	first_translator_en = glade_xml_get_widget (xml, "s_first_translator_en");
	language_en = glade_xml_get_widget (xml, "language_en");
	
	if (strlen ( gtk_entry_get_text (GTK_ENTRY (genere_en))) == 0 ||
		strlen ( gtk_entry_get_text (GTK_ENTRY (publish_house_en))) == 0 ||
		strlen ( gtk_entry_get_text (GTK_ENTRY (first_author_en))) == 0 ||
		strlen ( gtk_entry_get_text (GTK_ENTRY (isbn_en))) == 0 ||
		strlen ( gtk_entry_get_text (GTK_ENTRY (first_translator_en))) == 0 ||
		gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (publish_year_en)) == 0 ||
		gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (pages_number_en)) == 0 ||
		strlen ( gtk_entry_get_text (GTK_ENTRY (language_en))) == 0)	
	{
		show_message_dlg (_("Hint"), _("Some of additional fields (like \'Author\', "
						"\'Publish house\' or \'Genere\') are empty. There aren't "
						"required, but for better books organisation they should be "
						"filled in future."), 0);
	}
	
	return TRUE;
}

/*
 *	Funkcja zapisuje dane o nowej ksiazce w baziedanych
 */

void				s_insert_book			(SingleVolumeStruc	*book_data)	{
	sqlite3_stmt		*db_row;
	gint				status;
	gchar				sql_query	[VERY_LONG_STRING];
	
	g_sprintf (sql_query, "INSERT INTO single_volume_books "
			 "(id, "
										 
			 "orginal_title, "
			 "title, "
										 
			 "first_author, "
			 "second_author, "
			 "third_author, "
										 
			 "genere, "
			 "publish_house, "
										 
			 "first_translator, "
			 "second_translator, "
			 "third_translator, "
										 
			 "language, "
			 "orginal_language, "
										 
			 "isbn, "
			 "publish_year, "
			 "pages, "
										 
			 "description) VALUES "
			 "(NULL, "
			 "\'%s\', "
			 "\'%s\', "
			 "%d, " 
			 "%d, " 
			 "%d, " 
			 "%d, "
			 "%d, "
			 "%d, "
			 "%d, "
			 "%d, "
			 "%d, "
			 "%d, "
			 "\'%s\', "
			 "%d, "
			 "%d, "
			 "\'%s\');",		 
			 book_data->orginal_title,
			 book_data->title,
			 book_data->first_author,
			 book_data->second_author,
			 book_data->third_author,
			 book_data->genere,
			 book_data->publish_house,
			 book_data->first_translator,
			 book_data->second_translator,
			 book_data->third_translator,
			 book_data->language,
			 book_data->orginal_language,
			 book_data->isbn,
			 book_data->publish_year,
			 book_data->pages,
			 book_data->description);
			 
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Inserting book into database, SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	g_free (book_data);
}

/*
 *	Funkcja wyciaga z bazy danych informacje o ksiazce o wskazanym ID
 */

SingleVolumeStruc	*s_select_book_data	(gint	*id)	{
	SingleVolumeStruc	*book_data;
	sqlite3_stmt		*db_row;
	gchar				sql_query	[LONG_STRING];
	gint				status;
	
	book_data = g_new (SingleVolumeStruc, 1);
	
	g_sprintf (sql_query, "SELECT "
			 "id, "
										 
			 "orginal_title, "
			 "title , "
										 
			 "first_author, "
			 "second_author, "
			 "third_author, "
										 
			 "genere, "
			 "publish_house, "
										 
			 "first_translator, "
			 "second_translator, "
			 "third_translator, "
										 
			 "language, "
			 "orginal_language, "
										 
			 "isbn, "
			 "publish_year, "
			 "pages, "
										 
			 "description "
			 "FROM single_volume_books WHERE id=%d;", *id);

	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Selecting book's informations from database, SQLite result: %d\n", status);
	
	book_data->id = sqlite3_column_int (db_row, 0);
	g_sprintf (book_data->orginal_title, "%s", sqlite3_column_text (db_row, 1));
	g_sprintf (book_data->title, "%s", sqlite3_column_text (db_row, 2));
	book_data->first_author = sqlite3_column_int (db_row, 3);
	book_data->second_author = sqlite3_column_int (db_row, 4);
	book_data->third_author = sqlite3_column_int (db_row, 5);
	book_data->genere = sqlite3_column_int (db_row, 6);
	book_data->publish_house = sqlite3_column_int (db_row, 7);
	book_data->first_translator = sqlite3_column_int (db_row, 8);
	book_data->second_translator = sqlite3_column_int (db_row, 9);
	book_data->third_translator = sqlite3_column_int (db_row, 10);
	book_data->language = sqlite3_column_int (db_row, 11);
	book_data->orginal_language = sqlite3_column_int (db_row, 12);
	g_sprintf (book_data->isbn, "%s", sqlite3_column_text (db_row, 13));
	book_data->publish_year = sqlite3_column_int (db_row, 14);
	book_data->pages = sqlite3_column_int (db_row, 15);
	g_sprintf (book_data->description, "%s", sqlite3_column_text (db_row, 16));
	
	sqlite3_finalize (db_row);	 
	
	return book_data;
}

/*
 *	Funkcja wyswietla informacje o wybranej ksiazce w oknie 'main_win'
 *	Przy okazji funkcja dokonuje malej obrobki wyswietlanych danych, wiecej
 *	informacji na ten temat w kodzie funkcji.
 */

void		s_display_book_data		(SingleVolumeStruc	*book_data)	{
	GladeXML			*xml;
	GtkTextBuffer		*text_buffer;
	GtkWidget			*tmp;
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	gchar				string		[SHORT_STRING];
	gchar				item_name	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	xml = glade_get_widget_tree (main_win);
	g_printf ("<<< Displaying book's informations...\n");
	
	set_widget_sensinitive (main_win, "main_single_book_vbox", FALSE);
	
	/*	Wyswietlamy ID ksiazki	*/
	tmp = glade_xml_get_widget (xml, "s_book_id_lb");
	g_sprintf (string, "%d", book_data->id);
	gtk_label_set_text (GTK_LABEL (tmp), string);
	
	tmp = glade_xml_get_widget (xml, "s_title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), book_data->title);
	
	/*	Wyszukujemy autorow po numerach id zwroconych w strukturze 'book_data'	*/
	
	tmp = glade_xml_get_widget (xml, "s_author_lb");
	/*	Jezeli wszyscy autorzy sa ustawieni na 0, oznacza to, ze nie podano
		zadnego autora	*/
	if (book_data->first_author == 0 &&
		book_data->second_author == 0 &&
		book_data->third_author == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->first_author > 0)	{		
		get_author_name (item_name, book_data->first_author);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
		
		if (book_data->second_author > 0)	{
			get_author_name (item_name, book_data->second_author);
			g_sprintf (string, "%s\n%s", gtk_label_get_text (GTK_LABEL (tmp)),
						item_name);
			gtk_label_set_text (GTK_LABEL (tmp), string);
		}
		if (book_data->third_author > 0)	{
			get_author_name (item_name, book_data->third_author);
			g_sprintf (string, "%s\n%s", gtk_label_get_text (GTK_LABEL (tmp)),
						item_name);
			gtk_label_set_text (GTK_LABEL (tmp), string);
		}
	}
	else	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	
	/*	Wyciagamy gatunek z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "s_genere_lb");
	/*	Jezeli gatunek ustawiony jest na 0, oznacza to, ze nie podano
		zadnego gatunku	*/
	if (book_data->genere == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->genere > 0)	{
		get_genere_name (item_name, book_data->genere);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
	}
	
	/*	Wyciagamy wydawnictwo z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "s_publish_house_lb");
	/*	Jezeli wydawnictwo ustawione jest na 0, oznacza to, ze nie podano
		zadnego wydawnictwa	*/
	if (book_data->publish_house == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->publish_house > 0)	{
		get_publish_house_name (item_name, book_data->publish_house);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
	}
	
	/*	Wyciagamy jezyk z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "s_language_lb");
	/*	Jezeli jezyk  ustawiony jest na 0, oznacza to, ze nie podano
		zadnego jezyka	*/
	if (book_data->language == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->language > 0)	{
		get_language_name (item_name, book_data->language);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
	}
	
	tmp = glade_xml_get_widget (xml, "s_orginal_title_lb");
	if (strlen (book_data->orginal_title) == 0)	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else	{
		gtk_label_set_text (GTK_LABEL (tmp), book_data->orginal_title);
	}
	
	/*	Wyciagamy orginalny jezyk z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "s_orginal_language_lb");
	/*	Jezeli orginalny jezyk  ustawiony jest na 0, oznacza to, ze nie podano
		zadnego jezyka	*/
	if (book_data->orginal_language == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->orginal_language > 0)	{
		get_language_name (item_name, book_data->orginal_language);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
	}
	
	tmp = glade_xml_get_widget (xml, "s_isbn_lb");
	if (strlen (book_data->isbn) == 0)	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else	{
		gtk_label_set_text (GTK_LABEL (tmp), book_data->isbn);
	}
	
	tmp = glade_xml_get_widget (xml, "s_publish_year_lb");
	if (book_data->publish_year == 0)	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else {
		g_sprintf (string, "%d", book_data->publish_year);
		gtk_label_set_text (GTK_LABEL (tmp), string);
	}
	
	tmp = glade_xml_get_widget (xml, "s_pages_number_lb");
	if (book_data->pages == 0)	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else {
		g_sprintf (string, "%d", book_data->pages);
		gtk_label_set_text (GTK_LABEL (tmp), string);
	}
	
	/*	Wyszukujemy tlumaczy po numerach id zwroconych w strukturze 'book_data'	*/
	
	tmp = glade_xml_get_widget (xml, "s_translator_lb");
	/*	Jezeli wszyscy tlumacze sa ustawieni na 0, oznacza to, ze nie podano
		zadnego tlimacza	*/
	if (book_data->first_translator == 0 &&
		book_data->second_translator == 0 &&
		book_data->third_translator == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->first_translator > 0)	{
		g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->first_translator);
		sqlite3_prepare (database, sql_query, -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Selecting first translator from database, SQLite result: %d\n", status);	
		
		gtk_label_set_text (GTK_LABEL (tmp), (gpointer) sqlite3_column_text (db_row, 0));
		sqlite3_finalize (db_row);
		
		if (book_data->second_translator > 0)	{
			g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->second_translator);
			sqlite3_prepare (database, sql_query, -1, &db_row, 0);
			status = sqlite3_step (db_row);
			g_printf ("\t<<< Selecting second translator from database, SQLite result: %d\n", status);	
			
			g_sprintf (string, "%s\n%s", gtk_label_get_text (GTK_LABEL (tmp)),
						sqlite3_column_text (db_row, 0));
			gtk_label_set_text (GTK_LABEL (tmp), string);
			sqlite3_finalize (db_row);
		}
		if (book_data->third_translator > 0)	{
			g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->third_translator);
			sqlite3_prepare (database, sql_query, -1, &db_row, 0);
			status = sqlite3_step (db_row);
			g_printf ("\t<<< Selecting third translator from database, SQLite result: %d\n", status);	
			
			g_sprintf (string, "%s\n%s", gtk_label_get_text (GTK_LABEL (tmp)),
						sqlite3_column_text (db_row, 0));
			gtk_label_set_text (GTK_LABEL (tmp), string);
			sqlite3_finalize (db_row);
		}
	}
	else	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	
	tmp = glade_xml_get_widget (xml, "s_description_text");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, book_data->description, strlen (book_data->description));
	
	set_widget_sensinitive (main_win, "main_single_book_vbox", TRUE);
	g_free (book_data);
}

/*
 *	Funkcja usuwa jednotomowa ksiazke o wskazanym id
 */

void		s_remove_book		(gint	*id)	{
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	g_sprintf (sql_query, "DELETE FROM single_volume_books WHERE id=%d;", *id);
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("<<< Removing single volume book from database, SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja czysci wszytskie pola wyswieltajace informacje o ksiazkach
 *	jednotomowych w oknie 'main_win' i dezaktywuje przyciski odpowiedzialne
 *	za edycje, usuwanie itp. ksiazki jednotomowej o oknie 'main_wion'.
 *	Funkcja jest przydatna np. gdy usuniemy ksiazke z bazy danych.
 */

void				s_clear_main_win		(void)	{
	GladeXML			*xml;
	GtkTextBuffer		*text_buffer;
	GtkWidget			*tmp;
	
	xml = glade_get_widget_tree (main_win);
	tmp = glade_xml_get_widget (xml, "s_book_id_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_author_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_genere_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_publish_house_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_language_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_orginal_title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_orginal_language_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_isbn_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_publish_year_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_pages_number_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_translator_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (xml, "s_description_text");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, "", 0);
	
	set_widget_sensinitive (tmp, "s_remove_but", FALSE);
	set_widget_sensinitive (tmp, "s_edit_but", FALSE);
}

/*
 *	Funkcja laduje informacje o ksiazce o wskazanym id do okna 's_book_win'
 *	i przygotowuje dane na temat ksiazki do edycji.
 */

void		s_load_edit_win			(GtkWidget	*widget, gint	*id)	{
	SingleVolumeStruc	*book_data;
	GladeXML			*xml;
	GtkTextBuffer		*text_buffer;
	GtkWidget			*tmp;
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	gchar				string		[VERY_SHORT_STRING];
	gchar				item_name	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	
	xml = glade_get_widget_tree (widget);
	book_data = s_select_book_data (id);
	
	tmp = glade_xml_get_widget (xml, "book_id_lb");
	g_sprintf (string, "%d", *id);
	gtk_label_set_text (GTK_LABEL (tmp), string);
	
	tmp = glade_xml_get_widget (xml, "title_en");
	gtk_entry_set_text (GTK_ENTRY (tmp), book_data->title);
	
	/*	Wyciagamy gatunek z bazy danych	*/
	tmp = glade_xml_get_widget (xml, "genere_en");
	
	/*	Jezeli gatunek ustawiony jest na 0, oznacza to, ze nie podano
		zadnego gatunku	*/
	if (book_data->genere == 0)
	{
		gtk_entry_set_text (GTK_ENTRY (tmp), "");
	}
	else if (book_data->genere > 0)	{
		get_genere_name (item_name, book_data->genere);
		gtk_entry_set_text (GTK_ENTRY (tmp), item_name);
	}
	
	/*	Wyciagamy wydawnictwo z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "publish_house_en");
	/*	Jezeli wydawnictwo ustawione jest na 0, oznacza to, ze nie podano
		zadnego wydawnictwa	*/
	if (book_data->publish_house == 0)
	{
		gtk_entry_set_text (GTK_ENTRY (tmp), "");
	}
	else if (book_data->publish_house > 0)	{
		get_publish_house_name (item_name, book_data->publish_house);
		gtk_entry_set_text (GTK_ENTRY (tmp), item_name);
	}
	
	/*	Wyciagamy jezyk z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "language_en");
	/*	Jezeli jesyk ustawiony jest na 0, oznacza to, ze nie podano
		zadnego jezyka	*/
	if (book_data->language == 0)
	{
		gtk_entry_set_text (GTK_ENTRY (tmp), "");
	}
	else if (book_data->language > 0)	{
		get_language_name (item_name, book_data->language);
		gtk_entry_set_text (GTK_ENTRY (tmp), item_name);
	}
	
	/*	Wyciagamy autorow z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "s_first_author_en");
	/*	Jezeli pierwszy autor ustawiony jest na 0, oznacza to, ze nie podano
		zadnego gatunku, a tym samym nie logiczne jest, ze podano
		dodatkowych autorowm dlatego pole rozszerzajace "additional_authors_exp"
		zostaje dezaktywowane, jezeli natomias pole pierwszego autora ma wartosci
		wieksza niz 0, pole 'additional_authors_exp' zostanie aktywowane, a 
		dodatkowi autorzy zostana zaladowani do okna	*/
	if (book_data->first_author == 0)
	{
		gtk_entry_set_text (GTK_ENTRY (tmp), "");
		set_widget_sensinitive (tmp, "additional_authors_exp", FALSE);
	}
	else if (book_data->first_author > 0)	{
		get_author_name (item_name, book_data->first_author);
		gtk_entry_set_text (GTK_ENTRY (tmp), item_name);
		
		set_widget_sensinitive (tmp, "additional_authors_exp", TRUE);
		
		/*	Teraz sprawdzamy, czy nastepni autorzy sa podani, jezeli tak, to 
			ladujemy ich do okna i zaznaczamy odpowiednie 'patszki'	*/
		if (book_data->second_author > 0)	{
			tmp = glade_xml_get_widget (xml, "second_author_en");
			get_author_name (item_name, book_data->second_author);
			gtk_entry_set_text (GTK_ENTRY (tmp), item_name);
		}
		
		if (book_data->third_author > 0)	{
			tmp = glade_xml_get_widget (xml, "third_author_en");
			get_author_name (item_name, book_data->third_author);
			gtk_entry_set_text (GTK_ENTRY (tmp), item_name);
		}
	}
	
	tmp = glade_xml_get_widget (xml, "orginal_title_en");
	gtk_entry_set_text (GTK_ENTRY (tmp), book_data->orginal_title);
	
	/*	Wyciagamy jezyk z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "orginal_language_en");
	/*	Jezeli jesyk ustawiony jest na 0, oznacza to, ze nie podano
		zadnego jezyka	*/
	if (book_data->orginal_language == 0)
	{
		gtk_entry_set_text (GTK_ENTRY (tmp), "");
	}
	else if (book_data->orginal_language > 0)	{
		get_language_name (item_name, book_data->orginal_language);
		gtk_entry_set_text (GTK_ENTRY (tmp), item_name);
	}
	
	tmp = glade_xml_get_widget (xml, "isbn_en");
	gtk_entry_set_text (GTK_ENTRY (tmp), book_data->isbn);
	
	tmp = glade_xml_get_widget (xml, "publish_year_spin");
	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tmp), book_data->publish_year);
	
	tmp = glade_xml_get_widget (xml, "pages_number_spin");
	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tmp), book_data->pages);
	
	/*	Wyciagamy autorow z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "s_first_translator_en");
	/*	Patrz ladowanie autorow w tej funkcji	*/
	if (book_data->first_translator == 0)
	{
		gtk_entry_set_text (GTK_ENTRY (tmp), "");
		set_widget_sensinitive (tmp, "additional_translators_exp", FALSE);
	}
	else if (book_data->first_translator > 0)	{
		g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->first_translator);
		sqlite3_prepare (database, sql_query, -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Selecting first translator from database, SQLite result: %d\n", status);	
		
		gtk_entry_set_text (GTK_ENTRY (tmp), (gpointer) sqlite3_column_text (db_row, 0));
		sqlite3_finalize (db_row);
		
		set_widget_sensinitive (tmp, "additional_translators_exp", TRUE);
		
		/*	Teraz sprawdzamy, czy nastepni autorzy sa podani, jezeli tak, to 
			ladujemy ich do okna i zaznaczamy odpowiednie 'patszki'	*/
		if (book_data->second_translator > 0)	{
			tmp = glade_xml_get_widget (xml, "second_translator_en");
			g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->second_translator);
			sqlite3_prepare (database, sql_query, -1, &db_row, 0);
			status = sqlite3_step (db_row);
			g_printf ("\t<<< Selecting second translator from database, SQLite result: %d\n", status);	
		
			gtk_entry_set_text (GTK_ENTRY (tmp), (gpointer) sqlite3_column_text (db_row, 0));
			sqlite3_finalize (db_row);
			
			tmp = glade_xml_get_widget (xml, "s_second_tralslator_check");
			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp), TRUE);
		}
		
		if (book_data->third_translator > 0)	{
			tmp = glade_xml_get_widget (xml, "third_translator_en");
			g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->third_translator);
			sqlite3_prepare (database, sql_query, -1, &db_row, 0);
			status = sqlite3_step (db_row);
			g_printf ("\t<<< Selecting third translator from database, SQLite result: %d\n", status);	
		
			gtk_entry_set_text (GTK_ENTRY (tmp), (gpointer) sqlite3_column_text (db_row, 0));
			sqlite3_finalize (db_row);
			
			tmp = glade_xml_get_widget (xml, "s_third_translator_check");
			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp), TRUE);
		}
	}
	
	tmp = glade_xml_get_widget (xml, "description_text");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, book_data->description, strlen (book_data->description));
	
	g_free (book_data);
}

/*
 *	Funkcja zapisujezmodyfikowane informacje o ksiazce do bazy danych
 */

void		s_update_book		(SingleVolumeStruc	*book_data)	{
	sqlite3_stmt		*db_row;
	gint				status;
	gchar				sql_query	[VERY_LONG_STRING];
	
	g_sprintf (sql_query, "UPDATE single_volume_books SET "										 
		"orginal_title=\'%s\', "
		"title=\'%s\', "
								 
		"first_author=%d, "
		"second_author=%d, "
		"third_author=%d, "
								 
		"genere=%d, "
		"publish_house=%d, "
								 
		"first_translator=%d, "
		"second_translator=%d, "
		"third_translator=%d, "
										 
		"language=%d, "
		"orginal_language=%d, "
										 
		"isbn=\'%s\', "
		"publish_year=%d, "
		"pages=%d, "
								 
		"description=\'%s\' "
		"WHERE id=%d;",		 
		book_data->orginal_title,
		book_data->title,
		book_data->first_author,
		book_data->second_author,
		book_data->third_author,
		book_data->genere,
		book_data->publish_house,
		book_data->first_translator,
		book_data->second_translator,
		book_data->third_translator,
		book_data->language,
		book_data->orginal_language,
		book_data->isbn,
		book_data->publish_year,
		book_data->pages,
		book_data->description,
		book_data->id);
		
	sqlite3_prepare (database, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	
	g_printf ("<<< Updating book's informations from database, SQLite result: %d\n", status);
	
	sqlite3_finalize (db_row);
	g_free (book_data);
}

/*
 *	Funkcja wyswietla informacje o ksiazce w oknie 'property_win'
 */

void		s_show_book_data		(GtkWidget	*widget, gint	*id)	{
	GladeXML			*xml;
	GtkTextBuffer		*text_buffer;
	GtkWidget			*tmp;
	gint				status;
	gchar				sql_query	[SHORT_STRING];
	gchar				string		[SHORT_STRING];
	gchar				item_name	[SHORT_STRING];
	sqlite3_stmt		*db_row;
	SingleVolumeStruc	*book_data;
	
	xml = glade_get_widget_tree (widget);
	book_data = s_select_book_data (id);
	
	g_printf ("<<< Displaying book's informations...\n");
	
	tmp = glade_xml_get_widget (xml, "title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), book_data->title);
	
	/*	Wyszukujemy autorow po numerach id zwroconych w strukturze 'book_data'	*/
	
	tmp = glade_xml_get_widget (xml, "author_lb");
	/*	Jezeli wszyscy autorzy sa ustawieni na 0, oznacza to, ze nie podano
		zadnego autora	*/
	if (book_data->first_author == 0 &&
		book_data->second_author == 0 &&
		book_data->third_author == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->first_author > 0)	{		
		get_author_name (item_name, book_data->first_author);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
		
		if (book_data->second_author > 0)	{
			get_author_name (item_name, book_data->second_author);
			g_sprintf (string, "%s\n%s", gtk_label_get_text (GTK_LABEL (tmp)),
						item_name);
			gtk_label_set_text (GTK_LABEL (tmp), string);
		}
		if (book_data->third_author > 0)	{
			get_author_name (item_name, book_data->third_author);
			g_sprintf (string, "%s\n%s", gtk_label_get_text (GTK_LABEL (tmp)),
						item_name);
			gtk_label_set_text (GTK_LABEL (tmp), string);
		}
	}
	else	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	
	/*	Wyciagamy gatunek z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "genere_lb");
	/*	Jezeli gatunek ustawiony jest na 0, oznacza to, ze nie podano
		zadnego gatunku	*/
	if (book_data->genere == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->genere > 0)	{
		g_sprintf (sql_query, "SELECT genere FROM generes WHERE id=%d;",
					book_data->genere);
		sqlite3_prepare (database, sql_query, -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Selecting genre from database, SQLite result: %d\n", status);	
		
		gtk_label_set_text (GTK_LABEL (tmp), (gpointer) sqlite3_column_text (db_row, 0));
		sqlite3_finalize (db_row);
	}
	
	/*	Wyciagamy wydawnictwo z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "publish_house_lb");
	/*	Jezeli wydawnictwo ustawione jest na 0, oznacza to, ze nie podano
		zadnego wydawnictwa	*/
	if (book_data->publish_house == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->publish_house > 0)	{
		get_publish_house_name (item_name, book_data->publish_house);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
	}
	
	/*	Wyciagamy jezyk z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "language_lb");
	/*	Jezeli jezyk  ustawiony jest na 0, oznacza to, ze nie podano
		zadnego jezyka	*/
	if (book_data->language == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->language > 0)	{
		get_language_name (item_name, book_data->language);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
	}
	
	tmp = glade_xml_get_widget (xml, "orginal_title_lb");
	if (strlen (book_data->orginal_title) == 0)	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else	{
		gtk_label_set_text (GTK_LABEL (tmp), book_data->orginal_title);
	}
	
	/*	Wyciagamy orginalny jezyk z bazy danych	*/
	
	tmp = glade_xml_get_widget (xml, "orginal_language_lb");
	/*	Jezeli orginalny jezyk  ustawiony jest na 0, oznacza to, ze nie podano
		zadnego jezyka	*/
	if (book_data->orginal_language == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->orginal_language > 0)	{
		get_language_name (item_name, book_data->orginal_language);
		gtk_label_set_text (GTK_LABEL (tmp), item_name);
	}
	
	tmp = glade_xml_get_widget (xml, "isbn_lb");
	if (strlen (book_data->isbn) == 0)	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else	{
		gtk_label_set_text (GTK_LABEL (tmp), book_data->isbn);
	}
	
	tmp = glade_xml_get_widget (xml, "publish_year_lb");
	if (book_data->publish_year == 0)	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else {
		g_sprintf (string, "%d", book_data->publish_year);
		gtk_label_set_text (GTK_LABEL (tmp), string);
	}
	
	tmp = glade_xml_get_widget (xml, "pages_number_lb");
	if (book_data->pages == 0)	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else {
		g_sprintf (string, "%d", book_data->pages);
		gtk_label_set_text (GTK_LABEL (tmp), string);
	}
	
	/*	Wyszukujemy tlumaczy po numerach id zwroconych w strukturze 'book_data'	*/
	
	tmp = glade_xml_get_widget (xml, "translator_lb");
	/*	Jezeli wszyscy tlumacze sa ustawieni na 0, oznacza to, ze nie podano
		zadnego tlimacza	*/
	if (book_data->first_translator == 0 &&
		book_data->second_translator == 0 &&
		book_data->third_translator == 0)
	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	else if (book_data->first_translator > 0)	{
		g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->first_translator);
		sqlite3_prepare (database, sql_query, -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Selecting first translator from database, SQLite result: %d\n", status);	
		
		gtk_label_set_text (GTK_LABEL (tmp), (gpointer) sqlite3_column_text (db_row, 0));
		sqlite3_finalize (db_row);
		
		if (book_data->second_translator > 0)	{
			g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->second_translator);
			sqlite3_prepare (database, sql_query, -1, &db_row, 0);
			status = sqlite3_step (db_row);
			g_printf ("\t<<< Selecting second translator from database, SQLite result: %d\n", status);	
			
			g_sprintf (string, "%s\n%s", gtk_label_get_text (GTK_LABEL (tmp)),
						sqlite3_column_text (db_row, 0));
			gtk_label_set_text (GTK_LABEL (tmp), string);
			sqlite3_finalize (db_row);
		}
		if (book_data->third_translator > 0)	{
			g_sprintf (sql_query, "SELECT translator FROM translators WHERE id=%d;",
					book_data->third_translator);
			sqlite3_prepare (database, sql_query, -1, &db_row, 0);
			status = sqlite3_step (db_row);
			g_printf ("\t<<< Selecting third translator from database, SQLite result: %d\n", status);	
			
			g_sprintf (string, "%s\n%s", gtk_label_get_text (GTK_LABEL (tmp)),
						sqlite3_column_text (db_row, 0));
			gtk_label_set_text (GTK_LABEL (tmp), string);
			sqlite3_finalize (db_row);
		}
	}
	else	{
		gtk_label_set_text (GTK_LABEL (tmp), _("Unknown"));
	}
	
	tmp = glade_xml_get_widget (xml, "description_text");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, book_data->description, strlen (book_data->description));
	
	set_widget_sensinitive (tmp, "property_notebook", TRUE);
	
	g_free (book_data);
}

/*
 *	Funkcja kontroluje ilosc otwartych elementow 'GtkExpander' woknie 'main_win',
 *	w zakladce wyswieltajacej informacje o ksiazce wielotomowej. W sytuacji, gdy
 *	otwarte sa wszystkie elemnty rozszerzajace wysokosc okna osiaga 
 *	wartosc ponad 1200 pikseli, co moze uniemozliwic uzywanie okna przy 
 *	mniejszych rozdzielczosciach ekranu. Ta funkcja kontroluje ilosc otwartych
 *	elementow rozszerzajacych w tym samym czasie, ograniczajac ja do 1
 *	otwartego elementu 'GtkExpander'.
 *
 *	Argument 'mode' oznacza, ze otwarty zostal element:
 *	- 's_additional_informations_exp'
 *	- 's_description_exp'
 */

void		s_control_main_win_expanders	(gint	mode)	{
	GladeXML	*xml;
	GtkWidget	*s_additional_informations_exp;
	GtkWidget	*s_description_exp;
	
	xml = glade_get_widget_tree (main_win);
	s_additional_informations_exp = glade_xml_get_widget (xml,
				"s_additional_informations_exp");
	s_description_exp = glade_xml_get_widget (xml, "s_description_exp");
	
	switch (mode)	{
		case 0:
			gtk_expander_set_expanded (GTK_EXPANDER (s_description_exp), FALSE);
			break;
		case 1:
			gtk_expander_set_expanded (GTK_EXPANDER (s_additional_informations_exp), FALSE);
			break;
	}
}
